@@ -1,5 +1,6 @@
 """Object-specific python package to run automated tasks in the Chase Lab."""
 
+from .recycle import *
 from .ffsync import ffsync
 from .ffconcat import ffconcat
 from .lazytrim import lazytrim
@@ -14,7 +15,6 @@ from .json2tidycsv import json2tidycsv
 from .obtain_grand_m import obtain_grand_m
 from .concat_csv import concat_csv
 from .calc_dlc_mw import calc_dlc_mw
-from .recycle import trials, fwarnings
 from .dlcboxplot import dlcboxplot
 
 from .version import __version__, VERSION
