@@ -9,7 +9,11 @@ def trials():
         'second urine', 'cat alone (5)'
     ]
 
+def trials_abv():
+	
+    return ['FT', 'CA1', 'ST1', 'CA2', 'UT1', 'CA3', 'ST2', 'CA4', 'UT2', 'CA5']
+
 
 def fwarnings():
 
-	return warnings.filterwarnings("ignore")
+    return warnings.filterwarnings("ignore")
